@@ -1,4 +1,4 @@
-# Dancer2 plugin for easy create restfull web services
+# ABSTRACT: Rapid creation of REST web services with sessions and persistent data
 # Provides Routes for authentication, persistent session data
 # It can handle the formats : JSON , XML , YAML, PERL , HUMAN
 #
@@ -11,9 +11,6 @@
 #
 #   change setting :  $plugin->{app}->{config}->{SomeSetting} = 'foo';
 #
-# example of start command
-#
-#    sudo -u joe /usr/bin/site_perl/plackup --host 0.0.0.0 --port 65535 --server Starman --workers=10 -a /opt/TestService/bin/app.psgi --Reload /opt/TestService/lib,/opt/TestService/config.yml,/usr/share/perl5/site_perl/Dancer2/Plugin
 #
 # George Mpouras
 # george.mpouras@yandex.com
@@ -25,11 +22,10 @@
 package Dancer2::Plugin::WebService;
 use	Dancer2::Plugin;
 use	Storable;
-our	$VERSION = '3.009';
+our	$VERSION = '3.010';
 
 if ($^O =~ /(?i)MSWin/) {warn "Sorry windows operating system is not supported\n"; exit 1}
 
-
 # Make available the following functions to applications
 plugin_keywords qw/
 
@@ -878,20 +874,29 @@ unless (-d $dir) { $plugin->error(3); $plugin->errormessage('invalid or expired
 
 
 1;
+
 __END__
 
-
+=pod
 
 =encoding UTF-8
 =pod
 
+=head1 NAME
+
+Dancer2::Plugin::WebService - Rapid creation of REST web services with sessions and persistent data
+
+=head1 VERSION
+
+version 3.010
+
 =head2 NAME
 
-Dancer2::Plugin::WebService Easy restful web services with sessions and persistent data
+Dancer2::Plugin::WebService Rapid creation of REST web services with sessions and persistent data
 
 =head2 VERSION
 
-version 3.009
+version 3.010
 
 =head2 SYNOPSIS
 
@@ -960,11 +965,10 @@ Your script (example)
 
   dance;
 
-
 =head2 POLYMORPHISM
 
 Dancer2::Plugin::WebService can handle as input or output multiple formats
-	
+
   json
   xml
   yaml
@@ -1010,7 +1014,6 @@ or at your main script
 
   setting('plugins')->{'WebService'}->{'Routes'}->{'SomeRoute'} = 'private';
 
-
 =head2 BUILT-IN ROUTES
 
 There are some built in routes for your convenience.
@@ -1064,8 +1067,6 @@ It is private route as you can not logout without login . In order to logout you
   curl -X GET --data '{"SessionID":"0a1ad34505076d930c3f76c52645e54b"}'  localhost:65535/logout
   curl -X GET --data '{"SessionID":"0a8e4f0523dafa980ec35bcf29a5cc8c"}' 'localhost:65535/logout?from=json;to=xml'
 
-
-
 =head2 SESSIONS
 
 The sessions auto expired after some seconds of inactivity. You can change the amount of seconds either at the I<config.yml>
@@ -1096,7 +1097,7 @@ send the reply to the client. This should be the last route's statement
   RestReply('DATA_USER_SEND')         data send by the user
   RestReply('DATA_USER_ALL')          data send by the user with any addtions
   RestReply('k1')                     data send by the user only one key
-	
+
 =head3 get_data_user
 
 Retrieves data user send to WebService with his client e.g. curl or wget . We use this to do something usefull with user's data. This is normally the method you will use more often
@@ -1104,7 +1105,6 @@ Retrieves data user send to WebService with his client e.g. curl or wget . We us
   my ($var1, $var2) = get_data_user('k1', 'k2');    # return the selected keys
   my %hash          = get_data_user();              # return all data as hash
 
-
 =head3 set_data_user
 
 You can define extra data. Try to use this instead of common $variables , @arrays , etc because they are visible to other users of the service !
@@ -1142,20 +1142,7 @@ Deletes session data. You have to login prior using this method.
 
 =head2 INSTALLATION
 
-Install the following modules using e.g. the I<cpanm> utility
-
-  cpanm Data::Dumper
-  cpanm XML::Hash::XS
-  cpanm JSON::XS
-  cpanm YAML::XS
-  cpanm Moo
-  cpanm Plack
-  cpanm Plack::Middleware::Deflater
-  cpanm Starman
-  cpanm Dancer2
-  cpanm Dancer2::Plugin::WebService
-
-Create your WebService application e.g I<TestService> using the command inside e.g. the I</opt> folder
+After install I<Dancer2::Plugin::WebService> create your application e.g I<TestService> using the command inside e.g. the I</opt> folder
 
   cd /opt
   dancer2 gen --application TestService
@@ -1168,7 +1155,6 @@ Assuming that you will start the service as a non privileged user e.g. I<joe>
   chown -R joe:joe /var/log/TestService
   chown -R joe:joe /usr/local/sessions
 
-
 If you want compressed replies edit the file I</opt/TestService/bin/app.psgi>
 
   #!/usr/bin/perl
@@ -1179,7 +1165,7 @@ If you want compressed replies edit the file I</opt/TestService/bin/app.psgi>
   builder { enable 'Deflater'; TestService->to_app }
 
 Or if you have slow CPU use uncompressed replies by editing the file I</opt/TestService/bin/app.psgi>
-	
+
   #!/usr/bin/perl
   use FindBin;
   use lib "$FindBin::Bin/../lib";
@@ -1263,7 +1249,6 @@ Edit the file I</opt/TestService/config.yml>
           Active   : no
           Use sudo : no
 
-
 Write your code at the file  I</opt/TestService/lib/TestService.pm>
 
 e.g.
@@ -1319,7 +1304,6 @@ or without Plack
 
 if you want to install your WebService application as Linux service please readme the INSTALL
 
-
 =head2 AUTHENTICATION
 
 For using B<private> methods and persistent session data you have to login. B<login> is handled from external scripts/programs .
@@ -1350,7 +1334,6 @@ That means if you running the service as user joe , at the file B</etc/sudoers>
 
 For writing your own script please read the scripts howto.txt and review the existing scripts
 
-
 =head2 SEE ALSO
 
 B<Plack::Middleware::REST> Route PSGI requests for RESTful web applications
@@ -1372,4 +1355,15 @@ This software is copyright (c) 2017 by George Bouras
 It is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+George Bouras <george.mpouras@yandex.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by George Bouras.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
